import { Sequelize } from "sequelize";
import logger from "../logger/logger";
import dotenv from "dotenv";

dotenv.config();

const sequelize = new Sequelize(
  process.env.MARIADB_DATABASE as string,
  process.env.MARIADB_USER as string,
  process.env.MARIADB_PASSWORD as string,
  {
    host: process.env.MARIADB_HOST as string,
    port: Number(process.env.MARIADB_PORT),
    dialect: "mariadb",
    logging: false,
  }
);

sequelize
  .authenticate()
  .then(() => {
    logger.info("⚡️[DB]: Connection has been established successfully.");
  })
  .catch((err: Error) => {
    console.error("⚡️[DB]: Unable to connect to the database:", err);
  });

export default sequelize;
